@@ -9,17 +9,21 @@ Usage:
     python netcon.py
 """
 from __future__ import print_function
-from SystemConfiguration import SCNetworkConnectionCreateWithServiceID, SCNetworkConnectionScheduleWithRunLoop
+from SystemConfiguration import (
+    SCNetworkConnectionCreateWithServiceID,
+    SCNetworkConnectionScheduleWithRunLoop,
+)
 from CoreFoundation import CFRunLoopGetCurrent, CFRunLoopRun, kCFRunLoopCommonModes
 
+
 def connectionChanged(connection, status, info):
     print("Status of %s connection changed: %s"(info, status))
 
 
 def main():
     conn = SCNetworkConnectionCreateWithServiceID(
-        None, "Automatic",
-        connectionChanged, "foobar")
+        None, "Automatic", connectionChanged, "foobar"
+    )
 
     print(conn)
     assert conn is not None
@@ -28,5 +32,6 @@ def main():
     SCNetworkConnectionScheduleWithRunLoop(conn, loop, kCFRunLoopCommonModes)
     CFRunLoopRun()
 
+
 if __name__ == "__main__":
     main()
